CLARITE Documentation
=====================

CLeaning to Anlaysis: Reproducibility-based Interface for Traits and Exposures

.. toctree::
   :maxdepth: 2

   motivation
   installation
   usage
   complex_surveys
   release-history
